@@ -1,8 +1,11 @@
 # Author: Kelvin Lai <kelvin@firststreet.org>
 # Copyright: This module is owned by First Street Foundation
 
+# Internal Imports
+from firststreet.models.api import Api
 
-class EnvironmentalPrecipitation:
+
+class EnvironmentalPrecipitation(Api):
     """Creates an Environmental Precipitation object given a response
 
     Args:
@@ -10,5 +13,6 @@ class EnvironmentalPrecipitation:
     """
 
     def __init__(self, response):
+        super().__init__(response)
         self.fsid = response.get("fsid")
         self.projected = response.get("projected")
